// Code generated by django-cfg centrifugo codegen. DO NOT EDIT.

package {{ package_name }}

{% for type in types %}
// {{ type.doc }}
type {{ type.name }} struct {
{% for field in type.fields %}
{% if field.description %}
	// {{ field.description }}
{% endif %}
	{{ field.name }} {{ field.type }} {{ field.json_tag }}
{% endfor %}
}

{% endfor %}
