# Auto-generated by DjangoCFG - see CLAUDE.md

from .client import CfgDashboardActivityAPI
from .models import (
    ActivityEntry,
    QuickAction,
)
from .sync_client import SyncCfgDashboardActivityAPI

__all__ = [
    "CfgDashboardActivityAPI",
    "SyncCfgDashboardActivityAPI",
    "ActivityEntry",
    "QuickAction",
]