export default {
  'index': { display: 'hidden' },
  'overview': 'Overview',
  'cli-usage': 'CLI Usage',
  'groups': 'Groups',
  'generated-clients': 'Generated Clients',
  'troubleshooting': 'Troubleshooting'
}
