// Code generated by django-cfg/django_client - DO NOT EDIT.
// Generated at: {{ generated_at }}

package {{ package_name }}

{% if imports %}
import (
{% for import_path in imports %}
	"{{ import_path }}"
{% endfor %}
)
{% endif %}

{% for struct in structs %}
// {{ struct.doc | replace('\n', '\n// ') }}
type {{ struct.name }} struct {
{% for field in struct.fields %}
{% if field.description %}
	// {{ field.description | replace('\n', '\n\t// ') }}
{% endif %}
{% if field.deprecated %}
	// Deprecated: This field is deprecated.
{% endif %}
	{{ field.name }} {{ field.type }} {{ field.json_tag }}
{% endfor %}
}

{% endfor %}
