# Generated by Django 5.2.9 on 2025-12-21 03:23

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_cfg_accounts', '0010_twofactorsettings'),
    ]

    operations = [
        migrations.DeleteModel(
            name='TwoFactorSettings',
        ),
    ]
