export default {
  'overview': 'Overview',
  'quick-start': 'Quick Start',
  'configuration': 'Configuration',
  'flash-messages': 'Flash Messages',
  'field-types': 'Field Types',
  'filters': 'Filters',
  'examples': 'Examples',
  'api-reference': 'API Reference',
  'documentation': 'Documentation'
}
