export default {
  'overview': 'Overview',
  'architecture': 'Architecture',
  'configuration': 'Configuration',
  'examples': 'Examples',
  'job-cancellation': 'Job Cancellation',
  'monitoring': 'Monitoring',
  'deployment': 'Deployment'
}
