# Generated TypeScript Client

Auto-generated type-safe TypeScript client for Centrifugo WebSocket RPC.

## Installation

```bash
npm install centrifuge
```

## Usage

```typescript
import { CentrifugoRPCClient, APIClient } from './client';

async function main() {
  const rpc = new CentrifugoRPCClient(
    'ws://localhost:8000/connection/websocket',
    'your-jwt-token',
    'user-123'
  );

  await rpc.connect();

  const api = new APIClient(rpc);
  
{% if methods %}
{% for method in methods %}
  const result = await api.{{ method.name_ts }}(params);
{% endfor %}
{% endif %}

  await rpc.disconnect();
}
```

---
**Generated by django_cfg.apps.centrifugo.codegen**
