export default {
  'overview': 'Overview',
  'configuration': 'Configuration',
  'implementation': 'Implementation',
  'webhook-examples': 'Webhook Examples',
  'troubleshooting': 'Troubleshooting'
}
