"""
Generated API Client.

Auto-generated by django-cfg. Do not edit manually.

Usage:
    from django_cfg.modules.streamlit_admin.api.generated import SyncAPIClient

    api = SyncAPIClient("http://localhost:8000")
    api.set_token("your-jwt-token")

    with api:
        profile = api.cfg_user_profile.profile_retrieve()
        charts = api.cfg_dashboard_charts.dashboard_api_charts_activity_retrieve()

Note: Prefer using AdminAPI from parent module for auto-authentication:

    from django_cfg.modules.streamlit_admin.api import AdminAPI

    api = AdminAPI()  # auto base_url + auto token from session
"""

from .cfg import SyncAPIClient
from .cfg.client import APIClient

__all__ = [
    "SyncAPIClient",
    "APIClient",
]
