# Generated by Django 5.2.12 on 2026-03-22 19:26

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("django_cfg_accounts", "0016_alter_customuser_email"),
    ]

    operations = [
        migrations.AlterField(
            model_name="useractivity",
            name="object_type",
            field=models.CharField(blank=True, default="", max_length=50),
        ),
    ]
